/*
 * Copyright (C) 2021 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#pragma once
#include <android/hardware/camera/device/3.4/ICameraDeviceSession.h>
#include <mutex>
#include <set>
#include <vector>
#include "cached_stream_buffer.h"

namespace android::hardware::camera::device::V3_4::implementation {

class StreamBufferCache {
 public:
  std::shared_ptr<CachedStreamBuffer> get(uint64_t buffer_id);
  void remove(uint64_t buffer_id);
  void update(const StreamBuffer& buffer);
  void clear();
  void removeStreamsExcept(std::set<int32_t> streams_to_keep = {});

 private:
  std::mutex mutex_;
  std::vector<std::shared_ptr<CachedStreamBuffer>> cache_;
};

}  // namespace android::hardware::camera::device::V3_4::implementation
